@@ -1,15 +1,11 @@
-"""
-general
-"""
+# general
 
 
 class APITesterException(Exception):
     pass
 
 
-"""
-get method
-"""
+# get method
 
 
 class APITesterGetDataException(APITesterException):
@@ -24,90 +20,70 @@ class APITesterGetJsonException(APITesterException):
     pass
 
 
-"""
-put method
-"""
+# put method
 
 
 class APITesterPutException(APITesterException):
     pass
 
 
-"""
-delete method
-"""
+# delete method
 
 
 class APITesterDeleteException(APITesterException):
     pass
 
 
-"""
-put method
-"""
+# put method
 
 
 class APITesterPostException(APITesterException):
     pass
 
 
-"""
-head method
-"""
+# head method
 
 
 class APITesterHeadException(APITesterException):
     pass
 
 
-"""
-options method
-"""
+# options method
 
 
 class APITesterOptionsException(APITesterException):
     pass
 
 
-"""
-patch method
-"""
+# patch method
 
 
 class APITesterPatchException(APITesterException):
     pass
 
 
-"""
-session method
-"""
+# session method
 
 
 class APITesterSessionException(APITesterException):
     pass
 
 
-"""
-execute 
-"""
+# execute
 
 
 class APITesterExecuteException(APITesterException):
     pass
 
 
-"""
-json
-"""
+# json
 
 
 class APITesterJsonException(APITesterException):
     pass
 
 
-"""
-xml
-"""
+# xml
 
 
 class APITesterXMLException(APITesterException):
